ewa.audio.BaseAudioProvider

ewa :: audio :: BaseAudioProvider :: Class BaseAudioProvider |
[hide private]
[frames] | no frames]

# Class BaseAudioProvider

source code

    object --+
             |
            BaseAudioProvider

Known Subclasses:
  - FSAudioProvider
  - , StreamAudioProvider

Instance Methods | [hide private]
__init__(self, basedir) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
get_main_path(self, audioname) | source code
get_extra_master_path(self, audioname) | source code
get_extra_transcoded_path(self, audioname, mode, bitrate, samplerate, create=False) | source code
get_playlist(self, audioname, rule, create=True) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, basedir) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)